Django Mongo Database URL
=========================

Build Status:

 - Master: [![Build Status (master)](https://travis-ci.org/RyanBalfanz/django-mongo-database-url.png?branch=master)](https://travis-ci.org/RyanBalfanz/django-mongo-database-url)

 - Develop: [![Build Status (develop)](https://travis-ci.org/RyanBalfanz/django-mongo-database-url.png?branch=develop)](https://travis-ci.org/RyanBalfanz/django-mongo-database-url)


This is a copycat of kennethreitz/dj-database-url specifically for MongoDB URIs.

Installation
------------

pip install dj-mongo-database-url
